@@ -1,9 +1,9 @@
 #' Run Shiny App demonstrating the package
 #'
-#' @param ... passed to `shiny::runApp()`, e.g. port, launch.browser
+#' @param ... passed to [shiny::runApp()], e.g. `port`, `launch.browser`
 #'
 #' @examples
-#' if (interactive()) {
+#' if (interactive() && requireNamespace("shiny", quietly = TRUE)) {
 #'   bpbounds::runExample()
 #' }
 #' @export
@@ -12,5 +12,12 @@ runExample <- function(...) {
   if (appDir == "") {
     stop("Could not find example app.")
   }
+
+  if (!requireNamespace("shiny", quietly = TRUE)) {
+    stop(
+      "Package \"shiny\" must be installed to use this function.",
+      call. = FALSE
+    )
+  }
   shiny::runApp(appDir, ...)
 }
