@@ -1,15 +1,21 @@
-## ----setup, include = FALSE----------------------------------------------
+## ----setup, include = FALSE---------------------------------------------------
 knitr::opts_chunk$set(
   collapse = TRUE,
   comment = "#>"
 )
+if (!requireNamespace("dplyr", quietly = TRUE)) {
+  install.packages("dplyr", repos = "https://cloud.r-project.org/")
+}
+if (!requireNamespace("tidyr", quietly = TRUE)) {
+  install.packages("tidyr", repos = "https://cloud.r-project.org/")
+}
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 library(bpbounds)
 library(dplyr)
 library(tidyr)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 tab1dat <- data.frame(
   z = c(0, 0, 1, 1, 1, 1, 0, 0),
   x = c(0, 0, 0, 0, 1, 1, 1, 1),
@@ -21,16 +27,16 @@ tab1inddat <- uncount(tab1dat, freq)
 xt <- xtabs(~ x + y + z, data = tab1inddat)
 xt
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 p <- prop.table(xt, margin = 3)
 p
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 bpres <- bpbounds(p)
 sbp = summary(bpres)
 print(sbp)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 covyz = cov(tab1inddat$y, tab1inddat$z)
 
 covxz = cov(tab1inddat$x, tab1inddat$z)
@@ -38,7 +44,7 @@ covxz = cov(tab1inddat$x, tab1inddat$z)
 ace = covyz / covxz
 ace
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 condprob = c(.0064, 0, .9936, 0, .0028, .001, .1972, .799)
 tabp = array(condprob,
              dim = c(2, 2, 2),
@@ -50,7 +56,7 @@ tabp = array(condprob,
   as.table()
 bpbounds(tabp)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 gtab  = xtabs( ~ y + z, data = tab1inddat)
 gp = prop.table(gtab, margin = 2)
 gp
@@ -63,7 +69,7 @@ bpres2 = bpbounds(p = gp, t = tp, fmt = "bivariate")
 sbp2 = summary(bpres2)
 print(sbp2)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 mt3 <- c(.83, .05, .11, .01, .88, .06, .05, .01, .72, .05, .20, .03)
 p3 = array(mt3,
            dim = c(2, 2, 3),
@@ -77,7 +83,7 @@ bpres3 = bpbounds(p3)
 sbp3 = summary(bpres3)
 print(sbp3)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 set.seed(2232011)
 n = 10000
 z = rbinom(n, 1, .5)
@@ -96,7 +102,7 @@ bpres1 = bpbounds(p1)
 sbp1 = summary(bpres1)
 print(sbp1)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 tab2 = xtabs(~ x + y2 + z)
 p2 <- prop.table(tab2, margin = 3)
 
